# Opps

![Opps Open Source Content Management Platform](docs/source/_static/opps.jpg "Opps Open Source Content Management Platform")

An *Open Source Content Management Platform* for the **magazine** websites and **high-traffic**, using the Django Framework.

[![Build Status](https://drone.io/github.com/opps/opps/status.png)](https://drone.io/github.com/opps/opps/latest)
[![Build Status](https://travis-ci.org/opps/opps.png?branch=master)](https://travis-ci.org/opps/opps "Opps Travis")
[![PyPi version](https://pypip.in/v/opps/badge.png)](https://crate.io/packages/opps/)
[![PyPi downloads](https://pypip.in/d/opps/badge.png)](https://crate.io/packages/opps/)


# Contacts

The place to create issues is [opps's github issues](https://github.com/opps/opps/issues). The more information you send about an issue, the greater the chance it will get fixed fast.

If you are not sure about something, have a doubt or feedback, or just want to ask for a feature, feel free to join our mailing list, or, if you're on Freenode (IRC), you can join the [#opps](http://webchat.freenode.net/?channels=opps) chat.


# Run example

    $ git clone git@github.com:opps/opps.git
    $ cd opps
    $ python setup.py develop
    $ opps-admin.py startproject PROJECT_NAME
    $ cd PROJECT_NAME
    $ python manage.py runserver


# Sponsor

* [YACOWS](http://yacows.com.br/)


# License

Copyright 2013 Opps Project and other contributors.

Licensed under the [`MIT License`](http://www.oppsproject.org/en/latest/#license)